=========
Changelog
=========

Version 1.0.0, 2024-04-23
=========================

- Reader for netCDF H129 HSAF  and ERA5-Land product
- Compute climatology at different time scales
- Compute anomalies using 10 different methods
- Plotting functions for time series, climatology and anomalies
- Mapping functions for time series, climatology and anomalies

